@@ -8,7 +8,6 @@
 #include <sys/types.h>
 
 #include "fio.h"
-#include "os.h"
 
 static int extend_file(struct thread_data *td, struct fio_file *f)
 {
@@ -284,11 +283,15 @@ static int get_file_sizes(struct thread_data *td)
 
 	for_each_file(td, f, i) {
 		if (td->io_ops->open_file(td, f)) {
-			log_err("%s\n", td->verror);
-			err = 1;
+			if (td->error != ENOENT) {
+				log_err("%s\n", td->verror);
+				err = 1;
+			}
 			clear_error(td);
-		} else
-			td->io_ops->close_file(td, f);
+		} else {
+			if (td->io_ops->close_file)
+				td->io_ops->close_file(td, f);
+		}
 
 		if (f->real_file_size == -1ULL && td->o.size)
 			f->real_file_size = td->o.size / td->o.nr_files;
@@ -498,6 +501,12 @@ void add_file(struct thread_data *td, const char *fname)
 	memset(f, 0, sizeof(*f));
 	f->fd = -1;
 
+	/*
+	 * init function, io engine may not be loaded yet
+	 */
+	if (td->io_ops && (td->io_ops->flags & FIO_DISKLESSIO))
+		f->real_file_size = -1ULL;
+
 	if (td->o.directory)
 		len = sprintf(file_name, "%s/", td->o.directory);
 
