@@ -35,7 +35,6 @@
 #include <sys/mman.h>
 
 #include "fio.h"
-#include "os.h"
 
 unsigned long page_mask;
 unsigned long page_size;
@@ -991,6 +990,7 @@ static void reap_threads(int *nr_running, int *t_rate, int *m_rate)
 		/*
 		 * thread is not dead, continue
 		 */
+		pending++;
 		continue;
 reaped:
 		if (td->o.use_thread) {
@@ -1003,6 +1003,7 @@ reaped:
 		(*nr_running)--;
 		(*m_rate) -= td->o.ratemin;
 		(*t_rate) -= td->o.rate;
+		pending--;
 
 		if (td->error)
 			exit_value++;
@@ -1210,10 +1211,8 @@ int main(int argc, char *argv[])
 	if (parse_options(argc, argv))
 		return 1;
 
-	if (!thread_number) {
-		log_err("Nothing to do\n");
-		return 1;
-	}
+	if (!thread_number)
+		return 0;
 
 	ps = sysconf(_SC_PAGESIZE);
 	if (ps < 0) {
