@@ -13,13 +13,13 @@
 #include <string.h>
 #include <getopt.h>
 
-#include "compiler.h"
+#include "compiler/compiler.h"
 #include "list.h"
 #include "rbtree.h"
 #include "md5.h"
 #include "crc32.h"
-#include "arch.h"
-#include "os.h"
+#include "arch/arch.h"
+#include "os/os.h"
 #include "mutex.h"
 
 #ifdef FIO_HAVE_SYSLET
@@ -647,8 +647,9 @@ struct disk_util {
 	struct list_head list;
 
 	char *name;
+	char *sysfs_root;
 	char path[256];
-	dev_t dev;
+	int major, minor;
 
 	struct disk_util_stat dus;
 	struct disk_util_stat last_dus;
@@ -746,6 +747,21 @@ extern void dup_files(struct thread_data *, struct thread_data *);
 extern void print_thread_status(void);
 extern void print_status_init(int);
 
+/*
+ * disk util stuff
+ */
+#ifdef FIO_HAVE_DISK_UTIL
+extern void show_disk_util(void);
+extern void disk_util_timer_arm(void);
+extern void init_disk_util(struct thread_data *);
+extern void update_io_ticks(void);
+#else
+#define show_disk_util()
+#define disk_util_timer_arm()
+#define init_disk_util(td)
+#define update_io_ticks()
+#endif
+
 /*
  * Thread life cycle. Once a thread has a runstate beyond TD_INITIALIZED, it
  * will never back again. It may cycle between running/verififying/fsyncing.
